//[mahjong-utils](../../../../index.md)/[mahjongutils.models](../../index.md)/[Tile](../index.md)/[Companion](index.md)/[parseTiles](parse-tiles.md)

# parseTiles

[common]\
fun [parseTiles](parse-tiles.md)(text: [String](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)): [List](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-list/index.html)&lt;[Tile](../index.md)&gt;

将给定的牌文本转换为牌序列

#### Return

牌的序列

#### Parameters

common

| | |
|---|---|
| text | 牌的文本 |
